@@ -10,25 +10,26 @@ has usage => sub { shift->extract_usage };
 sub run {
   my ($self, @args) = @_;
 
-  my ($args, $options) = ([], {});
+  my ($args, $opts) = ([], {});
   getopt \@args,
-    'A|attempts=i'  => \$options->{attempts},
+    'A|attempts=i'  => \$opts->{attempts},
     'a|args=s'      => sub { $args = decode_json($_[1]) },
     'b|broadcast=s' => (\my $command),
-    'd|delay=i'     => \$options->{delay},
+    'd|delay=i'     => \$opts->{delay},
     'e|enqueue=s'   => \my $enqueue,
     'f|foreground'  => \my $foreground,
+    'H|history'     => \my $history,
     'L|locks'       => \my $locks,
     'l|limit=i'     => \(my $limit = 100),
     'o|offset=i'    => \(my $offset = 0),
-    'P|parent=s'    => ($options->{parents} = []),
-    'p|priority=i'  => \$options->{priority},
-    'q|queue=s'     => \$options->{queue},
+    'P|parent=s'    => sub { push @{$opts->{parents}}, $_[1] },
+    'p|priority=i'  => \$opts->{priority},
+    'q|queue=s'     => sub { push @{$opts->{queues}}, $opts->{queue} = $_[1] },
     'R|retry'       => \my $retry,
     'remove'        => \my $remove,
-    'S|state=s'     => \$options->{state},
+    'S|state=s'     => sub { push @{$opts->{states}}, $_[1] },
     's|stats'       => \my $stats,
-    't|task=s'      => \$options->{task},
+    't|task=s'      => sub { push @{$opts->{tasks}}, $_[1] },
     'U|unlock=s'    => \my $unlock,
     'w|workers'     => \my $workers;
 
@@ -37,29 +38,33 @@ sub run {
   return $minion->backend->broadcast($command, $args, \@args) if $command;
 
   # Enqueue
-  return say $minion->enqueue($enqueue, $args, $options) if $enqueue;
+  return say $minion->enqueue($enqueue, $args, $opts) if $enqueue;
 
   # Show stats
   return $self->_stats if $stats;
 
+  # Show history
+  return print dumper $minion->history if $history;
+
+  # Locks
+  return $minion->unlock($unlock) if $unlock;
+  return $self->_list_locks($offset, $limit, @args ? {names => \@args} : ())
+    if $locks;
+
   # Workers
   my $id = @args ? shift @args : undef;
   return $id ? $self->_worker($id) : $self->_list_workers($offset, $limit)
     if $workers;
 
-  # Locks
-  return $minion->unlock($unlock) if $unlock;
-  return $self->_list_locks($offset, $limit, {name => $id}) if $locks;
-
   # List jobs
-  return $self->_list_jobs($offset, $limit, $options) unless defined $id;
+  return $self->_list_jobs($offset, $limit, $opts) unless defined $id;
   die "Job does not exist.\n" unless my $job = $minion->job($id);
 
   # Remove job
   return $job->remove || die "Job is active.\n" if $remove;
 
   # Retry job
-  return $job->retry($options) || die "Job is active.\n" if $retry;
+  return $job->retry($opts) || die "Job is active.\n" if $retry;
 
   # Perform job in foreground
   return $minion->foreground($id) || die "Job is not ready.\n" if $foreground;
@@ -112,13 +117,13 @@ Minion::Command::minion::job - Minion job command
     ./myapp.pl minion job -w 23
     ./myapp.pl minion job -s
     ./myapp.pl minion job -f 10023
-    ./myapp.pl minion job -q important -t foo -S inactive
+    ./myapp.pl minion job -q important -t foo -t bar -S inactive
     ./myapp.pl minion job -e foo -a '[23, "bar"]'
     ./myapp.pl minion job -e foo -P 10023 -P 10024 -p 5 -q important
     ./myapp.pl minion job -R -d 10 10023
     ./myapp.pl minion job --remove 10023
     ./myapp.pl minion job -L
-    ./myapp.pl minion job -L some_lock
+    ./myapp.pl minion job -L some_lock some_other_lock
     ./myapp.pl minion job -b jobs -a '[12]'
     ./myapp.pl minion job -b jobs -a '[12]' 23 24 25
 
@@ -134,6 +139,7 @@ Minion::Command::minion::job - Minion job command
     -f, --foreground            Retry job in "minion_foreground" queue and
                                 perform it right away in the foreground (very
                                 useful for debugging)
+    -H, --history               Show queue history
     -h, --help                  Show this summary of available options
         --home <path>           Path to home directory of your application,
                                 defaults to the value of MOJO_HOME or
@@ -149,12 +155,12 @@ Minion::Command::minion::job - Minion job command
     -P, --parent <id>           One or more jobs the new job depends on
     -p, --priority <number>     Priority of new job, defaults to 0
     -q, --queue <name>          Queue to put new job in, defaults to "default",
-                                or list only jobs in this queue
+                                or list only jobs in these queues
     -R, --retry                 Retry job
         --remove                Remove job
-    -S, --state <name>          List only jobs in this state
+    -S, --state <name>          List only jobs in these states
     -s, --stats                 Show queue statistics
-    -t, --task <name>           List only jobs for this task
+    -t, --task <name>           List only jobs for these tasks
     -U, --unlock <name>         Release named lock
     -w, --workers               List workers instead of jobs, or show
                                 information for a specific worker
