@@ -30,6 +30,10 @@ Mojolicious::Plugin::Minion - Minion job queue plugin
   # Mojolicious::Lite (choose a backend)
   plugin Minion => {Pg => 'postgresql://postgres@/test'};
 
+  # Share the database connection cache (PostgreSQL backend)
+  helper pg => sub { state $pg = Mojo::Pg->new('postgresql://postgres@/test') };
+  plugin Minion => {Pg => app->pg};
+
   # Add tasks to your application
   app->minion->add_task(slow_log => sub {
     my ($job, $msg) = @_;
@@ -80,6 +84,6 @@ Register plugin in L<Mojolicious> application.
 
 =head1 SEE ALSO
 
-L<Minion>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
+L<Minion>, L<Mojolicious::Guides>, L<http://mojolicious.org>.
 
 =cut
